diff --git a/wpilibcExamples/examples.xml b/wpilibcExamples/examples.xml
index 21de404d97..5450e84779 100644
--- a/wpilibcExamples/examples.xml
+++ b/wpilibcExamples/examples.xml
@@ -184,7 +184,7 @@
Arcade Drive
- An example program which demonstrates the use of Arcade Drive with the RobotDrive class
+ An example program which demonstrates the use of Arcade Drive with the DifferentialDrive class
Getting Started with C++
Robot and Motor
@@ -200,7 +200,7 @@
Mecanum Drive
- An example program which demonstrates the use of Mecanum Drive with the RobotDrive class
+ An example program which demonstrates the use of Mecanum Drive with the MecanumDrive class
Getting Started with C++
Robot and Motor
diff --git a/wpilibcExamples/src/main/cpp/examples/Gyro/src/Robot.cpp b/wpilibcExamples/src/main/cpp/examples/Gyro/src/Robot.cpp
index 021b17e4b1..6d70655109 100644
--- a/wpilibcExamples/src/main/cpp/examples/Gyro/src/Robot.cpp
+++ b/wpilibcExamples/src/main/cpp/examples/Gyro/src/Robot.cpp
@@ -15,10 +15,8 @@
/**
* This is a sample program to demonstrate how to use a gyro sensor to make a
- * robot drive
- * straight. This program uses a joystick to drive forwards and backwards while
- * the gyro
- * is used for direction keeping.
+ * robot drive straight. This program uses a joystick to drive forwards and
+ * backwards while the gyro is used for direction keeping.
*/
class Robot : public frc::IterativeRobot {
public:
@@ -27,9 +25,9 @@ public:
}
/**
- * The motor speed is set from the joystick while the RobotDrive turning
- * value is assigned from the error between the setpoint and the gyro
- * angle.
+ * The motor speed is set from the joystick while the DifferentialDrive
+ * turning value is assigned from the error between the setpoint and the
+ * gyro angle.
*/
void TeleopPeriodic() override {
double turningValue = (kAngleSetpoint - m_gyro.GetAngle()) * kP;
diff --git a/wpilibcExamples/src/main/cpp/examples/MecanumDrive/src/Robot.cpp b/wpilibcExamples/src/main/cpp/examples/MecanumDrive/src/Robot.cpp
index 3183dd4382..d3b3347752 100644
--- a/wpilibcExamples/src/main/cpp/examples/MecanumDrive/src/Robot.cpp
+++ b/wpilibcExamples/src/main/cpp/examples/MecanumDrive/src/Robot.cpp
@@ -11,8 +11,8 @@
#include
/**
- * This is a demo program showing how to use Mecanum control with the RobotDrive
- * class.
+ * This is a demo program showing how to use Mecanum control with the
+ * MecanumDrive class.
*/
class Robot : public frc::IterativeRobot {
public:
diff --git a/wpilibcExamples/src/main/cpp/examples/PacGoat/src/Subsystems/DriveTrain.cpp b/wpilibcExamples/src/main/cpp/examples/PacGoat/src/Subsystems/DriveTrain.cpp
index 02f70cbb27..5afdaaa92b 100644
--- a/wpilibcExamples/src/main/cpp/examples/PacGoat/src/Subsystems/DriveTrain.cpp
+++ b/wpilibcExamples/src/main/cpp/examples/PacGoat/src/Subsystems/DriveTrain.cpp
@@ -25,8 +25,8 @@ DriveTrain::DriveTrain()
// frc::LiveWindow::GetInstance()->AddActuator("DriveTrain", "Back Right
// CIM", &m_backRightCIM);
- // Configure the RobotDrive to reflect the fact that all our motors are
- // wired backwards and our drivers sensitivity preferences.
+ // Configure the DifferentialDrive to reflect the fact that all our
+ // motors are wired backwards and our drivers sensitivity preferences.
m_robotDrive.SetSafetyEnabled(false);
m_robotDrive.SetExpiration(0.1);
m_robotDrive.SetMaxOutput(1.0);
diff --git a/wpilibcExamples/src/main/cpp/templates/sample/Robot.cpp b/wpilibcExamples/src/main/cpp/templates/sample/Robot.cpp
index ca5c7fe0bb..34c7253a03 100644
--- a/wpilibcExamples/src/main/cpp/templates/sample/Robot.cpp
+++ b/wpilibcExamples/src/main/cpp/templates/sample/Robot.cpp
@@ -17,7 +17,7 @@
#include
/**
- * This is a demo program showing the use of the RobotDrive class.
+ * This is a demo program showing the use of the DifferentialDrive class.
* The SampleRobot class is the base of a robot application that will
* automatically call your Autonomous and OperatorControl methods at the right
* time as controlled by the switches on the driver station or the field
diff --git a/wpilibcExamples/src/main/cpp/examples/ArcadeDrive/src/Robot.cpp b/wpilibcExamples/src/main/cpp/examples/ArcadeDrive/src/Robot.cpp
index a2838369c0..cb03dd8ccd 100644
--- a/wpilibcExamples/src/main/cpp/examples/ArcadeDrive/src/Robot.cpp
+++ b/wpilibcExamples/src/main/cpp/examples/ArcadeDrive/src/Robot.cpp
@@ -5,16 +5,19 @@
/* the project. */
/*----------------------------------------------------------------------------*/
-#include
+#include
+#include
+#include
+#include
/**
* This is a demo program showing the use of the RobotDrive class.
* Runs the motors with arcade steering.
*/
class Robot : public frc::IterativeRobot {
- frc::Spark m_left{0};
- frc::Spark m_right{1};
- frc::RobotDrive m_robotDrive{m_left, m_right};
+ frc::Spark m_leftMotor{0};
+ frc::Spark m_rightMotor{1};
+ frc::DifferentialDrive m_robotDrive{m_leftMotor, m_rightMotor};
frc::Joystick m_stick{0};
public:
@@ -5,16 +5,19 @@
/**
- * This is a demo program showing the use of the RobotDrive class.
+ * This is a demo program showing the use of the DifferentialDrive class.
* Runs the motors with arcade steering.
*/